@@ -28,11 +28,12 @@ RE_MONTH	= "(0?[1-9]|1[0-2])"
 RE_DAY		= "([12][0-9]|30|31|0?[1-9])"
 RE_HOUR		= "(2[0-3]|[0-1]?[0-9])"
 RE_MINUTE	= "([0-5]?[0-9])"
-RE_SECOND	= "((#{RE_MINUTE}|60)(\.[0-9]*)?)"
+RE_SECOND	= "((#{RE_MINUTE}|60)(\\.[0-9]*)?)"
 RE_NAME		= "(%|[a-zA-Z][a-zA-Z_]*([0-9]+[a-zA-Z_]+)*)"
 
 RE_DATE		= "#{RE_YEAR}-#{RE_MONTH}-#{RE_DAY}"
-RE_TIME		= "#{RE_HOUR}(:#{RE_MINUTE}(:#{RE_SECOND})?)?"
+RE_TIME		= "#{RE_HOUR}((:[0-5]?[0-9]|[0-5][0-9])(:#{RE_SECOND})?)?"
+RE_HandM	= "#{RE_HOUR}((:[0-5]?[0-9]|[0-5][0-9]))?"
 
 def next_token
 
@@ -84,6 +85,7 @@ def next_token
     if :DATE_SEEN === @lexstat \
     and @copy.sub!(%r{^#{RE_TIME}[ \t]*}, '') then
 	h, m, s = $1, $3, $5
+        m = m.sub(/:/,'') if m
 	s = 0 if s.nil?
 	@lexstat = :TIME_SEEN
 	return [:TIME, ((h.to_i * 60 + m.to_i) * 60 + Float(s))]
@@ -110,23 +112,17 @@ def next_token
     end
 
     if :TIME_SEEN === @lexstat \
-    and @copy.sub!(%r{^([-+]?)#{RE_HOUR}:?#{RE_MINUTE}[ \t]*}, '') then
-	sgn, h, m = $1, $2, $3
+    and @copy.sub!(%r{^([-+]?)#{RE_HandM}[ \t]*}, '') then
+	sgn, h, m = $1, $2, $4
+        m = m.sub(/:/,'') if m
 	@lexstat = nil
 	h = h.to_i
 	h = -h if sgn == "-"
 	m = m.to_i
+	m = -m if sgn == "-"
 	return [:ZONE, ((h * 60) + m)]
     end
 
-    if :TIME_SEEN === @lexstat \
-    and @copy.sub!(%r{^([-+]?)#{RE_HOUR}:?[ \t]*}, '') then
-	sgn, h = $1, $2
-	h = -h if sgn == "-"
-	@lexstat = nil
-	return [:ZONE, (h.to_i * 60)]
-    end
-
     if @copy.sub!(%r{^#{RE_NAME}}, '') then
 	@lexstat = nil
 	return [:NAME, $1]
