@@ -15,6 +15,15 @@ class NumberNode < TerminalNode
     alias :value :a
     alias :factor :a
 
+    def == (other)
+      case other
+      when NumberNode
+	@a == other.a
+      else
+	false
+      end
+    end
+
     def add_eval(another)
 	raise TypeError unless NumberNode === another
 	NumberNode.new(@a + another.value)
